@@ -11,6 +11,25 @@ This middleware is best added last to the middlewares that will be called
 by your application since a middleware that does not dispatch to another
 middleware will inhibit this middleware.
 
+
+Usage
+=====
+
+.. code-block:: python
+
+    from flask import Flask
+    from flask_gordon.middleware import BeforeFirstCall
+
+
+    def once_before_first_call():
+        print("Hello World")
+
+
+    app = Flask(__name__)
+    app.wsgi_app = BeforeFirstCall(app.wsgi_app, once_before_first_call)
+    app.run()
+
+
 Classes
 =======
 
